@@ -1,6 +1,6 @@
 #!/bin/sh
 
-# Copyright (C) 2019-2022 Internet Systems Consortium, Inc. ("ISC")
+# Copyright (C) 2019-2023 Internet Systems Consortium, Inc. ("ISC")
 #
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -25,10 +25,10 @@ prefix="/usr/local"
 
 # Include utilities. Use installed version if available and
 # use build version if it isn't.
-if [ -e ${prefix}/share/kea/scripts/admin-utils.sh ]; then
+if test -f "${prefix}/share/kea/scripts/admin-utils.sh"; then
     . "${prefix}/share/kea/scripts/admin-utils.sh"
 else
-    . "/usr/ports/pobj/kea-2.2.0-mysql/kea-2.2.0/src/bin/admin/admin-utils.sh"
+    . "/local/pobj/kea-2.4.0-mysql/kea-2.4.0/src/bin/admin/admin-utils.sh"
 fi
 
 # First argument must be the expected schema version <major>.<minor>
@@ -109,10 +109,14 @@ DELETE FROM hosts;
 DELETE FROM ipv6_reservations;
 DELETE FROM lease4;
 DELETE FROM lease4_stat;
+DELETE FROM lease4_pool_stat;
 DELETE FROM lease6;
 DELETE FROM lease6_stat;
+DELETE FROM lease6_pool_stat;
 DELETE FROM logs;
 DELETE FROM lease4_stat_by_client_class;
 DELETE FROM lease6_stat_by_client_class;
+DELETE FROM lease6_relay_id;
+DELETE FROM lease6_remote_id;
 COMMIT;
 EOF
